@@ -32,7 +32,7 @@
 
 #include "imagelib/effects/kpEffectReduceColors.h"
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 
 //---------------------------------------------------------------------
 
@@ -69,7 +69,7 @@ static QImage::Format DepthToFormat (int depth)
 QImage kpEffectReduceColors::convertImageDepth (const QImage &image, int depth, bool dither)
 {
 #if DEBUG_KP_EFFECT_REDUCE_COLORS
-    kDebug () << "kpeffectreducecolors.cpp:ConvertImageDepth() changing image (w=" << image.width ()
+    qCDebug(kpLogImagelib) << "kpeffectreducecolors.cpp:ConvertImageDepth() changing image (w=" << image.width ()
                << ",h=" << image.height ()
                << ") depth from " << image.depth ()
                 << " to " << depth
@@ -107,7 +107,7 @@ QImage kpEffectReduceColors::convertImageDepth (const QImage &image, int depth,
     if (depth == 1 && !dither)
     {
     #if DEBUG_KP_EFFECT_REDUCE_COLORS
-        kDebug () << "\tinvoking convert-to-depth 1 hack";
+        qCDebug(kpLogImagelib) << "\tinvoking convert-to-depth 1 hack";
     #endif
         QRgb color0 = 0, color1 = 0;
         bool color0Valid = false, color1Valid = false;
@@ -115,9 +115,9 @@ QImage kpEffectReduceColors::convertImageDepth (const QImage &image, int depth,
         bool moreThan2Colors = false;
 
         QImage monoImage (image.width (), image.height (), QImage::Format_MonoLSB);
-        monoImage.setNumColors (2);
+        monoImage.setColorCount (2);
     #if DEBUG_KP_EFFECT_REDUCE_COLORS
-        kDebug () << "\t\tinitialising output image w=" << monoImage.width ()
+        qCDebug(kpLogImagelib) << "\t\tinitialising output image w=" << monoImage.width ()
                    << ",h=" << monoImage.height ()
                    << ",d=" << monoImage.depth ()
                    << endl;
@@ -139,7 +139,7 @@ QImage kpEffectReduceColors::convertImageDepth (const QImage &image, int depth,
                     color0Valid = true;
                     monoImage.setPixel (x, y, 0);
                 #if DEBUG_KP_EFFECT_REDUCE_COLORS
-                    kDebug () << "\t\t\tcolor0=" << (int *) color0
+                    qCDebug(kpLogImagelib) << "\t\t\tcolor0=" << (int *) color0
                                << " at x=" << x << ",y=" << y << endl;
                 #endif
                 }
@@ -149,14 +149,14 @@ QImage kpEffectReduceColors::convertImageDepth (const QImage &image, int depth,
                     color1Valid = true;
                     monoImage.setPixel (x, y, 1);
                 #if DEBUG_KP_EFFECT_REDUCE_COLORS
-                    kDebug () << "\t\t\tcolor1=" << (int *) color1
+                    qCDebug(kpLogImagelib) << "\t\t\tcolor1=" << (int *) color1
                                << " at x=" << x << ",y=" << y << endl;
                 #endif
                 }
                 else
                 {
                 #if DEBUG_KP_EFFECT_REDUCE_COLORS
-                    kDebug () << "\t\t\timagePixel=" << (int *) imagePixel
+                    qCDebug(kpLogImagelib) << "\t\t\timagePixel=" << (int *) imagePixel
                                << " at x=" << x << ",y=" << y
                                << " moreThan2Colors - abort hack" << endl;
                 #endif
@@ -184,12 +184,12 @@ QImage kpEffectReduceColors::convertImageDepth (const QImage &image, int depth,
         Qt::ThresholdAlphaDither |
         (dither ? Qt::PreferDither : Qt::AvoidDither));
 #if DEBUG_KP_EFFECT_REDUCE_COLORS
-    kDebug () << "\tformat: before=" << image.format ()
+    qCDebug(kpLogImagelib) << "\tformat: before=" << image.format ()
               << "after=" << retImage.format ();
 #endif
 
 #if DEBUG_KP_EFFECT_REDUCE_COLORS && 0
-    kDebug () << "After colour reduction:";
+    qCDebug(kpLogImagelib) << "After colour reduction:";
     for (int y = 0; y < image.height (); y++)
     {
         for (int x = 0; x < image.width (); x++)
